=========================
Developing gocept.jasmine
=========================

:Author:
    `Sebastian Wehrmann <http://gocept.com/>`_ <sw@gocept.com>

:PyPI page:
    http://pypi.python.org/pypi/gocept.jasmine/

:Issues:
    https://github.com/gocept/gocept.jasmine/issues

:Source code:
    https://github.com/gocept/gocept.jasmine

:Current change log:
    https://raw.githubusercontent.com/gocept/gocept.jasmine/master/CHANGES.txt
